AclSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • AclSdkPlatform
Implementers

Constructors

AclSdkPlatform()
Constructs a AclSdkPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

generateDeviceId() → Future<String>
getBatteryInfo() → Future<Map<String, dynamic>?>
getDeviceInfo() → Future<Map<String, dynamic>?>
getDeviceResourceAudit() → Future<Map<String, dynamic>?>
getNetworkAudit() → Future<Map<String, dynamic>?>
getNotificationsDir() → Future<String?>
getPlatformVersion() → Future<String?>
getUsageStatsDailyByPackage({required int fromMillisecondsSinceEpoch, required int toMillisecondsSinceEpoch}) → Future<List?>
goToAppUsageSetting() → Future<void>
goToNotificationListenerSetting() → Future<void>
isNotificationListenerRunning() → Future<bool>
isPackageUsageStatsEnable() → Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ AclSdkPlatform
The default instance of AclSdkPlatform to use.
getter/setter pair