AppConfigCreateInput class

Constructors

AppConfigCreateInput({required String partnerId, required String apiEndpoint, required String apiKey, required String apiSecret, required String appBundle})
Rename lenderId to partnerId from v0.1.1

Properties

apiEndpoint → String
final
apiKey → String
final
apiSecret → String
final
appBundle → String
final
hashCode → int
The hash code for this object.
no setterinherited
partnerId → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited